==> centreon-web-24.04.19.tar.gz: centreon-web-24.04.19/www/api/class/centreon_menu.class.php <==
<?php
/**
 * Copyright 2005-2018 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */

use CentreonLegacy\Core\Menu\Menu;

require_once dirname(__FILE__) . "/webService.class.php";

class CentreonMenu extends CentreonWebService implements CentreonWebServiceDiInterface
{
    private $dependencyInjector;
    /**
     * Get the init menu on loading page
     *
     * Argument:
     *   page -> int - The current page
     *
     * Method: GET
     */
    public function getMenu()
    {
        if (!isset($_SESSION['centreon'])) {
            throw new \RestUnauthorizedException('Session does not exists.');
        }
        /**
         * Initialize the language translator
         */
        $this->dependencyInjector['translator'];
        $menu = new Menu($this->pearDB, $_SESSION['centreon']->user);

        return $menu->getMenu();
    }

    /**
     * Define the dependency injector
     *
     * @param \Pimple\Container $dependencyInjector
     */
    public function finalConstruct(\Pimple\Container $dependencyInjector)
    {
        $this->dependencyInjector = $dependencyInjector;
    }
}

==> centreon-web-24.10.16.tar.gz: centreon-web-24.10.16/www/api/class/centreon_menu.class.php <==
<?php
/**
 * Copyright 2005-2018 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */

use CentreonLegacy\Core\Menu\Menu;
use Pimple\Container;

require_once __DIR__ . "/webService.class.php";

/**
 * Class
 *
 * @class CentreonMenu
 */
class CentreonMenu extends CentreonWebService implements CentreonWebServiceDiInterface
{
    /** @var CentreonDB */
    public $pearDB;
    /** @var Container */
    private $dependencyInjector;

    /**
     * Get the init menu on loading page
     *
     * Argument:
     *   page -> int - The current page
     *
     * Method: GET
     *
     * @return array
     * @throws RestUnauthorizedException
     */
    public function getMenu()
    {
        if (!isset($_SESSION['centreon'])) {
            throw new RestUnauthorizedException('Session does not exists.');
        }
        /**
         * Initialize the language translator
         */
        $this->dependencyInjector['translator'];
        $menu = new Menu($this->pearDB, $_SESSION['centreon']->user);

        return $menu->getMenu();
    }

    /**
     * Define the dependency injector
     *
     * @param Container $dependencyInjector
     *
     * @return void
     */
    public function finalConstruct(Container $dependencyInjector): void
    {
        $this->dependencyInjector = $dependencyInjector;
    }
}
